OutCol

Struct OutCol 

pub struct OutCol<A> {
    pub edge: Option<Edge>,
    /* private fields */
}
Represents some output pin that might have an edge attached. If an edge is attached, the parent node can send data to some receiving node’s aggregator.

Fields

edge: Option<Edge>