macro_rules! impl_io {
($($Gen:ident : $Idx:tt), +) => { ... };
}Expand description
Implemets the IntoIoSignature trait for any tupel of the for (A, B, C, …) denoted as impl_io!(A:0, B:1, C:2, …);
macro_rules! impl_io {
($($Gen:ident : $Idx:tt), +) => { ... };
}Implemets the IntoIoSignature trait for any tupel of the for (A, B, C, …) denoted as impl_io!(A:0, B:1, C:2, …);